Extract coefficients from a linear mixed model.
# S3 method for mlmm
coef(object, effects = "contrast", ordering = "parameter", ...)a mlmm object.
[character] By default will output the estimate for the hypothesis being tests.
But can also output all model coefficients ("all"),
or only coefficients relative to the mean ("mean" or "fixed"),
or only coefficients relative to the variance structure ("variance"),
or only coefficients relative to the correlation structure ("correlation").
[character] should the output be ordered by type of parameter (parameter) or by model (by).
passed to coef.Wald_lmm.