Compute confidence intervals for several linear mixed models.
# S3 method for mlmm
confint(
object,
parm = NULL,
level = 0.95,
method = NULL,
ordering = "parameter",
...
)an mlmm object, output of mlmm.
Not used. For compatibility with the generic method.
[numeric,0-1] the confidence level of the confidence intervals.
[character] type of adjustment for multiple comparisons: one of "none", "bonferroni", "single-step", "single-step2", or "pool".
[character] should the output be ordered by type of parameter (parameter) or by model (by).
Only relevant for mlmm objects.
other arguments are passed to confint.Wald_lmm.
Statistical inference following pooling is performed according to Rubin's rule whose validity requires the congeniality condition of Meng (1994).
Meng X. L.(1994). Multiple-imputation inferences with uncongenial sources of input. Statist. Sci.9, 538–58.