Export estimates, standard errors, degrees of freedom, confidence intervals (CIs) and p-values for the mean coefficients of a linear mixed model.
# S3 method for lmm
model.tables(x, columns, ...)a lmm object.
[character vector] Columns to be output.
Can be any of "estimate", "se", "statistic", "df", "null", "lower", "upper", "p.value".
arguments to be passed to the confint method. Should not contain the argument column.
[character] type of adjustment for multiple comparisons, one of "none", "bonferroni", ..., "fdr", "single-step", "single-step2".
Alternatively, method for combining the estimates, one of "average", "pool.se", "pool.gls", "pool.rubin".
This function simply calls confint with a specific value for the argument column.