- fitted
a lmm object.
- effects
[character vector] name of the parameters who will be constrained.
Alternatively can be the type of parameters, e.g. "mean", "variance", "correlation", or "all".
- profile.likelihood
[logical] should profile likelihood be performed? Otherwise varying one parameter at a time around the MLE while keeping the other constant).
- maxpts
[integer, >0] number of points use to discretize the likelihood, maxpts points smaller than the MLE and maxpts points higher than the MLE.
- conf.level
[numeric, 0-1] the confidence level of the confidence intervals used to decide about the range of values for each parameter.
- trace
[logical] Show the progress of the execution of the function.
- transform.sigma
[character] Transformation used on the variance coefficient for the reference level. One of "none", "log", "square", "logsquare" - see details.
- transform.k
[character] Transformation used on the variance coefficients relative to the other levels. One of "none", "log", "square", "logsquare", "sd", "logsd", "var", "logvar" - see details.
- transform.rho
[character] Transformation used on the correlation coefficients. One of "none", "atanh", "cov" - see details.
- transform.names
[logical] Should the name of the coefficients be updated to reflect the transformation that has been used?
- ...
Not used. For compatibility with the generic method.